@@ -1,13 +1,13 @@
 package Perinci::Sub::Wrapper;
 
-our $DATE = '2015-02-19'; # DATE
-our $VERSION = '0.74'; # VERSION
+our $DATE = '2015-02-26'; # DATE
+our $VERSION = '0.75'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Function::Fallback::CoreOrPP qw(clone);
 use Perinci::Sub::Normalize qw(normalize_function_metadata);
@@ -1366,7 +1366,7 @@ Perinci::Sub::Wrapper - A multi-purpose subroutine wrapping framework
 
 =head1 VERSION
 
-This document describes version 0.74 of Perinci::Sub::Wrapper (from Perl distribution Perinci-Sub-Wrapper), released on 2015-02-19.
+This document describes version 0.75 of Perinci::Sub::Wrapper (from Perl distribution Perinci-Sub-Wrapper), released on 2015-02-26.
 
 =head1 SYNOPSIS
 
